%% Tilting of the dipoles
% Atom Number Density      = 1250 ppum

ppum                                          = 1250;

%% theta = 0

Lx                                            = 8:0.4:11;
Ly                                            = 4:0.4:11;
cluster                                       = parcluster;

% Create a combined index for all i, j pairs
[I, J]          = ndgrid(1:numel(Lx), 1:numel(Ly));
totalIterations = numel(I);

% Parallel loop over all combinations of i, j
parfor (k = 1:totalIterations, cluster)
    i = I(k);
    j = J(k);
    lx = Lx(i);
    ly = Ly(j);

    % Initialize OptionsStruct
    OptionsStruct = struct;

    % Assign values to OptionsStruct
    OptionsStruct.NumberOfAtoms           = ppum * (lx*ly);     
    OptionsStruct.DipolarPolarAngle       = deg2rad(15);
    OptionsStruct.DipolarAzimuthAngle     = 0;
    OptionsStruct.ScatteringLength        = 75.00;        

    OptionsStruct.TrapFrequencies         = [0, 0, 500];
    OptionsStruct.TrapPotentialType       = 'None';

    OptionsStruct.NumberOfGridPoints      = [128, 128];
    OptionsStruct.Dimensions              = [lx, ly];      
    OptionsStruct.TimeStepSize            = 1E-3;            % in s
    OptionsStruct.MinimumTimeStepSize     = 1E-5;            % in s
    OptionsStruct.TimeCutOff              = 2E6;             % in s
    OptionsStruct.EnergyTolerance         = 5E-10;
    OptionsStruct.ResidualTolerance       = 1E-05;
    OptionsStruct.NoiseScaleFactor        = 0.05;
    OptionsStruct.IncludeDDICutOff        = false;
    
    OptionsStruct.MaxIterations           = 10;      
    OptionsStruct.VariationalWidth        = 1.20;       
    OptionsStruct.WidthLowerBound         = 0.01;
    OptionsStruct.WidthUpperBound         = 12;
    OptionsStruct.WidthCutoff             = 1e-2;

    OptionsStruct.PlotLive                = false;
    OptionsStruct.JobNumber               = (i - 1) * num_inner + j;
    OptionsStruct.RunOnGPU                = true;
    OptionsStruct.SaveData                = true;
    OptionsStruct.SaveDirectory           = sprintf('./Results/Data_TiltingOfDipoles/TransitionAngle/OptimalSystemSize/Hz500/Degree%i', round(rad2deg(OptionsStruct.DipolarPolarAngle)));

    options = Helper.convertstruct2cell(OptionsStruct);
    
    solver = VariationalSolver2D.DipolarGas(options{:});
    pot = VariationalSolver2D.Potentials(options{:});
    solver.Potential = pot.trap();

    % Run Solver
    [Params, Transf, psi, V, VDk] = solver.run();    
end
